<?php
/**
 * Auto_Affiliate_Schedule Class
 *
 * @since  1.0.0
 * @package Auto Affiliate
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Affiliate_Schedule' ) ) :

   class Auto_Affiliate_Schedule {

       /**
        * Plugin instance
        *
        * @var null
        */
       private static $instance = null;

       /**
        * Return the plugin instance
        *
        * @since 1.0.0
        * @return Auto_Affiliate_Schedule
        */
       public static function get_instance() {
           if ( is_null( self::$instance ) ) {
               self::$instance = new self();
           }

           return self::$instance;
       }

       /**
       * Auto_Affiliate_Schedule constructor.
       *
       * @since 1.0.0
       */
       public function __construct() {
           // Add a custom interval
           add_filter( 'cron_schedules', array( $this, 'affiliate_add_cron_interval' ) );
           // Setup Cron Job
           $this->cron_setup();
       }

       /**
        * Add a custom interval
        *
        * @since 1.0.0
        */
       public function affiliate_add_cron_interval( $schedules ) {
           $schedules['once_affiliate_a_minute'] = array(
               'interval' => 60,
               'display'  => esc_html__( 'Once Affiliate Job a Minute' )
           );
           $schedules['once_affiliate_a_day'] = array(
            'interval' => 60*60*24,
            'display'  => esc_html__( 'Once Affiliate Job a Day' )
           );
           return $schedules;
       }

       /**
        * Setup Cron Job
        *
        * @since 1.0.0
        */
       public function cron_setup(){
         if ( ! wp_next_scheduled( 'affiliate_cron_hook' ) ) {
            wp_schedule_event( time(), 'once_affiliate_a_minute', 'affiliate_cron_hook' );
         }

         // Add Cron Job Hook Function
         add_action( 'affiliate_cron_hook', array( $this, 'affiliate_cron_exec' )  );

         // New version check
         if ( ! wp_next_scheduled( 'affiliate_version_cron_hook' ) ) {
            wp_schedule_event( time(), 'once_affiliate_a_day', 'affiliate_version_cron_hook' );
         }

         // Add Cron Job Hook Function
         add_action( 'affiliate_version_cron_hook', array( $this, 'affiliate_version_cron_exec' )  );

       }

       /**
        * Version Check Cron Job Execute
        *
        * @since 1.0.0
        */
        public function affiliate_version_cron_exec(){
            // Check new version and sent notify email
            if ( $new = auto_affiliate_check_for_newer() ) {
            $history = get_site_option( '_auto_affiliate_premium_notify_new' );
            if ( ! $history || ! is_array( $history ) ) {
                $history = array();
            }
            if ( ! in_array( $new['ver'], $history ) ) {
                auto_affiliate_send_email( 'new_version', 'Read more: https://wpautoaffiliate.com/' );
                $history[] = $new['ver'];
                update_site_option( '_auto_affiliate_premium_notify_new', $history );
            }
           }
        }

       /**
        * Cron Job Execute
        *
        * @since 1.0.0
        */
       public function affiliate_cron_exec(){
           $current_time = time();

           // Run campaigns job here
           $models = Auto_Affiliate_Custom_Form_Model::model()->get_all_models();

           $campaigns = $models['models'];

           foreach($campaigns as $key=>$model){
               $settings = $model->settings;
               // Run this campaign when time on schedule time
               if($current_time >= $settings['next_run_time']){
                   $model->run_campaign();
               }
           }

           // Send email report
           $global_settings = get_option( 'auto_affiliate_global_settings', array() );

           if ( empty( $global_settings[ 'next_report_time' ] ) ) {
               $global_settings[ 'next_report_time'] = time() + 7*60*60*24;
               update_option( 'auto_affiliate_global_settings', $global_settings );
           }

		   if($current_time >= $global_settings['next_report_time']){
               $result = auto_affiliate_send_email('report');
               $update_frequency = isset($global_settings[ 'update_frequency']) ? $global_settings[ 'update_frequency'] : 7;
               $update_frequency_unit = isset($global_settings[ 'update_frequency_unit']) ? $global_settings[ 'update_frequency_unit'] : 'Days';
               // update next report time
               $global_settings[ 'next_report_time'] = time() + auto_affiliate_calculate_next_time($update_frequency, $update_frequency_unit);
			   update_option( 'auto_affiliate_global_settings', $global_settings );
           }
       }

       /**
        * Print Current Cron Jobs
        *
        * @since 1.0.0
        */
       public function affiliate_print_tasks() {
           echo '<pre>'; print_r( _get_cron_array() ); echo '</pre>';
       }

   }

endif;
